DepthwiseConv2DOperation

Struct DepthwiseConv2DOperation 

pub struct DepthwiseConv2DOperation<'c> { /* private fields */ }
A depthwise_conv2d operation. Depthwise 2D Convolution operator..

Performs 2D convolutions separately over each channel of the given tensor input, using the weight tensor. Implementations may choose to skip calculation of multiplies in the padding area.

Implementations

Source

impl<'c> DepthwiseConv2DOperation<'c>

pub fn name() -> &'static str

Returns a name.

pub fn as_operation(&self) -> &Operation<'c>

Returns a generic operation.

pub fn builder( context: &'c Context, location: Location<'c>, ) -> DepthwiseConv2DOperationBuilder<'c, Unset, Unset, Unset, Unset, Unset, Unset, Unset, Unset, Unset, Unset>

Creates a builder.

pub fn output(&self) -> Result<OperationResult<'c, '_>, Error>

pub fn input(&self) -> Result<Value<'c, '_>, Error>

pub fn weight(&self) -> Result<Value<'c, '_>, Error>

pub fn bias(&self) -> Result<Value<'c, '_>, Error>

pub fn input_zp(&self) -> Result<Value<'c, '_>, Error>

pub fn weight_zp(&self) -> Result<Value<'c, '_>, Error>

pub fn pad(&self) -> Result<Attribute<'c>, Error>

pub fn set_pad(&mut self, value: Attribute<'c>)

pub fn stride(&self) -> Result<Attribute<'c>, Error>

pub fn set_stride(&mut self, value: Attribute<'c>)

pub fn dilation(&self) -> Result<Attribute<'c>, Error>

pub fn set_dilation(&mut self, value: Attribute<'c>)

pub fn acc_type(&self) -> Result<TypeAttribute<'c>, Error>

pub fn set_acc_type(&mut self, value: TypeAttribute<'c>)

pub fn local_bound(&self) -> Result<Attribute<'c>, Error>

pub fn set_local_bound(&mut self, value: Attribute<'c>)

pub fn remove_local_bound(&mut self) -> Result<(), Error>