pub struct ScatterOperation<'c> { /* private fields */ }Expand description
A scatter operation. Scatter operation..
The values_out tensor is set to the values_in tensor with data modified as follows: data from the input tensor is inserted at the positions specified by the indices tensor. N is the number of batches, W the number of indices in each batch, K the range of each index and C the number data channels for each index. It is not permitted to repeat the same output index within a single SCATTER operation and so each output index occurs at most once. It follows that K >= W. In use cases that require multiple updates to the same output position, these must be decomposed into multiple SCATTER operations.
Implementations
Sourceimpl<'c> ScatterOperation<'c>
impl<'c> ScatterOperation<'c>
Sourcepub fn as_operation(&self) -> &Operation<'c>
pub fn as_operation(&self) -> &Operation<'c>
Returns a generic operation.
Sourcepub fn builder(
context: &'c Context,
location: Location<'c>,
) -> ScatterOperationBuilder<'c, Unset, Unset, Unset, Unset>
pub fn builder( context: &'c Context, location: Location<'c>, ) -> ScatterOperationBuilder<'c, Unset, Unset, Unset, Unset>
Creates a builder.
pub fn values_out(&self) -> Result<OperationResult<'c, '_>, Error>
pub fn values_in(&self) -> Result<Value<'c, '_>, Error>
pub fn indices(&self) -> Result<Value<'c, '_>, Error>
pub fn input(&self) -> Result<Value<'c, '_>, Error>